@@ -17,6 +17,12 @@ mime_url = 'https://someurl.com/'
 get_pkg_data_contents = partial(
     get_pkg_data_contents, package=__package__, encoding='binary')
 
+try:
+    from PIL import Image  # noqa: F401
+    HAS_PILLOW = True
+except ImportError:
+    HAS_PILLOW = False
+
 
 @pytest.fixture()
 def mime(mocker):
@@ -35,16 +41,17 @@ def mime(mocker):
 
 
 @pytest.mark.usefixtures('mime')
+@pytest.mark.skipif('not HAS_PILLOW')
 def test_mime_object_maker():
 
-    assert 'Text content' == mime_object_maker(mime_url+'mime-text',
+    assert 'Text content' == mime_object_maker(mime_url + 'mime-text',
                                                'text/csv')
 
-    img = mime_object_maker(mime_url+'image', 'image/jpeg')
+    img = mime_object_maker(mime_url + 'image', 'image/jpeg')
     assert img
     assert 'JPEG' == img.format
 
-    fits = mime_object_maker(mime_url+'fits', 'application/fits')
+    fits = mime_object_maker(mime_url + 'fits', 'application/fits')
     assert 2 == len(fits)
 
     # error cases
