@@ -3,15 +3,12 @@
 """
 Tests for pyvo.io.vosi
 """
-from __future__ import (
-    absolute_import, division, print_function, unicode_literals)
-
 import pyvo.io.vosi as vosi
 
 from astropy.utils.data import get_pkg_data_filename
 
 
-class TestAvailability(object):
+class TestAvailability:
     def test_availability(self):
         availability = vosi.parse_availability(get_pkg_data_filename(
             "data/availability.xml"))
