@@ -5,7 +5,7 @@ a module for basic VO Registry interactions.
 A VO registry is a database of VO resources--data collections and
 services--that are available for VO applications.  Typically, it is
 aware of the resources from all over the world.  A registry can find
-relevent data collections and services through search
+relevant data collections and services through search
 queries--typically, subject-based.  The registry responds with a list
 of records describing matching resources.  With a record in hand, the
 application can use the information in the record to access the
@@ -19,6 +19,7 @@ standardized TAP-based services.
 import functools
 import itertools
 import os
+import textwrap
 import warnings
 
 from astropy import table
@@ -33,7 +34,7 @@ from ..io.vosi import vodataservice
 from ..utils.formatting import para_format_desc
 
 
-__all__ = ["search", "get_RegTAP_query",
+__all__ = ["search", "get_RegTAP_query", "Interface",
            "RegistryResource", "RegistryResults", "ivoid2service"]
 
 REGISTRY_BASEURL = os.environ.get("IVOA_REGISTRY", "http://reg.g-vo.org/tap"
@@ -234,9 +235,12 @@ def search(*constraints: rtcons.Constraint,
 
     Returns
     -------
-    ~pyvo.registry.regtap.RegistryResults`
+    ~pyvo.registry.RegistryResults`
        a container holding a table of matching resource (e.g. services)
 
+    See Also
+    --------
+    RegistryResults
     """
     service = get_RegTAP_service()
     query = RegistryQuery(
@@ -349,12 +353,16 @@ class _BrowserService:
     services.
     """
 
-    def __init__(self, access_url):
-        self.access_url = access_url
+    def __init__(self, access_url, capability_description=None):
+        self.baseurl = access_url
+        self.capability_description = capability_description
+
+    def __repr__(self):
+        return f"BrowserService(baseurl : '{self.baseurl}', description : '{self.capability_description}')"
 
     def search(self):
         import webbrowser
-        webbrowser.open(self.access_url, 2)
+        webbrowser.open(self.baseurl, 2)
 
 
 class Interface:
@@ -381,11 +389,13 @@ class Interface:
         "ivo://ivoa.net/std/sla": sla.SLAService,
         "ivo://ivoa.net/std/tap": tap.TAPService}
 
-    def __init__(self, access_url, standard_id, intf_type, intf_role):
+    def __init__(self, access_url, *, standard_id=None,
+                 intf_type=None, intf_role=None, capability_description=None):
         self.access_url = access_url
-        self.standard_id = standard_id or None
-        self.type = intf_type or None
-        self.role = intf_role or None
+        self.standard_id = standard_id
+        self.type = intf_type
+        self.role = intf_role
+        self.capability_description = capability_description
         self.is_standard = self.role == "std"
 
         if self.standard_id is not None:
@@ -393,13 +403,26 @@ class Interface:
         else:
             self.is_vosi = False
 
+        # a service is user visible if it has a corresponding service class
+        if self.standard_id is not None and self.standard_id != "":
+            service_type = self.standard_id.split("#")[0]  # remove possible suffixes/standard keys
+            self.is_user_visible = service_type in self.service_for_standardid
+        # or if it is a webpage
+        else:
+            self.is_user_visible = self.type == "vr:webbrowser"
+
     def __repr__(self):
-        return (f"Interface({self.access_url!r}, standard_id={self.standard_id!r},"
-                f" intf_type={self.type!r}, intf_role={self.role!r})")
+        if not self.standard_id or self.standard_id is None:
+            return (f"Interface(type={self.type!r}, "
+                    f"description={self.capability_description!r}, "
+                    f"url={self.access_url!r})")
+        return (f"Interface(type={self.standard_id.rsplit('/')[-1]!r}, "
+                f"description={self.capability_description!r}, "
+                f"url={self.access_url!r})")
 
     def to_service(self, *, session=None):
         if self.type == "vr:webbrowser":
-            return _BrowserService(self.access_url)
+            return _BrowserService(self.access_url, self.capability_description)
 
         if self.standard_id is None or not self.is_standard:
             raise ValueError("This is not a standard interface.  PyVO"
@@ -412,9 +435,15 @@ class Interface:
                              f" standard id {self.standard_id}.")
 
         if service_class == sia2.SIA2Service:
-            return service_class(self.access_url, check_baseurl=False, session=session)
+            return service_class(self.access_url,
+                                 capability_description=self.capability_description,
+                                 check_baseurl=False,
+                                 session=session)
         else:
-            return service_class(self.access_url, session=session)
+            return service_class(
+                self.access_url,
+                capability_description=self.capability_description,
+                session=session)
 
     def supports(self, standard_id):
         """returns true if we believe the interface should be able to talk
@@ -484,27 +513,33 @@ class RegistryResource(dalq.Record):
         (f"\n  ivo_string_agg(COALESCE(intf_type, ''), '{TOKEN_SEP}')",
             "intf_types"),
         (f"\n  ivo_string_agg(COALESCE(intf_role, ''), '{TOKEN_SEP}')",
-            "intf_roles")]
+            "intf_roles"),
+        (f"\n  ivo_string_agg(COALESCE(cap_description, ''), '{TOKEN_SEP}')",
+            "cap_descriptions")]
 
-    def __init__(self, results, index, session=None):
+    def __init__(self, results, index, *, session=None):
         dalq.Record.__init__(self, results, index, session=session)
 
         self._mapping["access_urls"
                       ] = self._parse_pseudo_array(self._mapping["access_urls"])
         self._mapping["standard_ids"] = [
             regularize_SIA2_id(id) for id in
-                self._parse_pseudo_array(self._mapping["standard_ids"])]
+            self._parse_pseudo_array(self._mapping["standard_ids"])]
         self._mapping["intf_types"
                       ] = self._parse_pseudo_array(self._mapping["intf_types"])
         self._mapping["intf_roles"
                       ] = self._parse_pseudo_array(self._mapping["intf_roles"])
+        self._mapping["cap_descriptions"
+                      ] = self._parse_pseudo_array(self._mapping["cap_descriptions"])
 
-        self.interfaces = [Interface(props[0], standard_id=props[1], intf_type=props[2], intf_role=props[3])
+        self.interfaces = [Interface(props[0], standard_id=props[1], intf_type=props[2],
+                                     intf_role=props[3], capability_description=props[4])
                            for props in itertools.zip_longest(
             self["access_urls"],
             self["standard_ids"],
             self["intf_types"],
-            self["intf_roles"])]
+            self["intf_roles"],
+            self["cap_descriptions"])]
 
     @staticmethod
     def _parse_pseudo_array(literal):
@@ -581,7 +616,7 @@ class RegistryResource(dalq.Record):
     def creators(self):
         """
         The creator(s) of the resource
-        in the ordergiven by the resource record author
+        in the order given by the resource record author
         """
         return self.get("creator_seq", default="", decode=True).split(";")
 
@@ -698,10 +733,11 @@ class RegistryResource(dalq.Record):
                    if (intf.standard_id or intf.type == "vr:webbrowser")
                    and not intf.is_vosi)
 
-    def get_interface(self,
+    def get_interface(self, *,
                       service_type: str,
-                      lax: bool = True,
-                      std_only: bool = False):
+                      lax: bool = False,
+                      std_only: bool = False,
+                      keyword: str = None):
         """returns a regtap.Interface class for service_type.
 
         The meaning of the parameters is as for get_service.  This
@@ -755,26 +791,33 @@ class RegistryResource(dalq.Record):
                           if ((not std_only) or intf.is_standard)
                           and not intf.is_vosi
                           and ((not service_type) or intf.supports(service_type))]
-
         if not candidates:
-            raise ValueError(
-                "No matching interface.")
+            raise ValueError("No matching interface.")
+
+        if keyword is not None:
+            candidates = [candidate for candidate in candidates
+                          if candidate.capability_description is not None
+                          and keyword in candidate.capability_description]
+
         if len(candidates) > 1 and not lax:
-            raise ValueError("Multiple matching interfaces found."
-                             "  Perhaps pass in service_type or use a Servicetype"
-                             " constrain in the registry.search?  Or use lax=True?")
+            raise ValueError("Multiple matching interfaces found. If you know that they are all equivalent, "
+                             "use 'lax=True'.\n"
+                             "Otherwise, the search can be constrained by specifying a 'service_type' "
+                             "or a 'keyword' to be found in the service description."
+                             " You might also want to see all the available services"
+                             " with `pyvo.registry.regtap.RegistryResource.list_interfaces()`.")
 
         return candidates[0]
 
-    def get_service(self,
-                    service_type: str = None,
-                    lax: bool = True,
+    def get_service(self, service_type: str = None, *,
+                    lax: bool = False,
+                    keyword: str = None,
                     session: object = None):
         """
         return an appropriate DALService subclass for this resource that
         can be used to search the resource using service_type.
 
-        Raise a ValueError if the service_type is not offerend on
+        Raise a ValueError if the service_type is not offered on
         the resource (or no standard service is offered).  With
         lax=False, also raise a ValueError if multiple interfaces
         exist for the given service_type.
@@ -804,6 +847,16 @@ class RegistryResource(dalq.Record):
             function choose the first matching capability by default
             Pass lax=False to instead raise a DALQueryError.
 
+        keyword : str
+            A keyword that should be in the service description.
+            Some resources have multiple capabilities ("services") of the same
+            type (see list_interfaces for a discussion).  get_service will
+            usually raise a ValueError in that case. Passing a
+            ``keyword`` that uniquely identifies the capability to
+            query will make get_service predictably return the desired
+            service.  Use list_interfaces to find such a unique description
+            fragment.
+
         session : object
             optional requests session to use to communicate with the service
             constructed.
@@ -816,9 +869,13 @@ class RegistryResource(dalq.Record):
             services) is returned.  For ``web`` services, what is returned is
             an opaque service object that has a ``search()`` method simply
             opening a web browser on the access URL.
+
+        See Also
+        --------
+        list_interfaces : return a list with all the available services.
         """
-        return self.get_interface(service_type, lax, std_only=True
-                                  ).to_service(session=session)
+        return self.get_interface(service_type=service_type, lax=lax, std_only=True,
+                                  keyword=keyword).to_service(session=session)
 
     @property
     def service(self):
@@ -829,12 +886,50 @@ class RegistryResource(dalq.Record):
         constrained the service type; otherwise, many resources will
         have multiple capabilities.  Use get_service instead in
         such cases.
+
+        See Also
+        --------
+        get_service : select a service of a specific service type.
+        list_interfaces : return a list with all the available interfaces to services.
         """
         if self._service is not None:
             return self._service
-        self._service = self.get_service(None, True)
+        self._service = self.get_service(service_type=None, lax=True)
         return self._service
 
+    def list_interfaces(self, service_type: str = None):
+        """List the interfaces to services available for this registry record.
+
+        The interface objects in the list can then be used to instantiate the service with
+        the  `~pyvo.registry.regtap.Interface.to_service` method.
+
+        Parameters
+        ----------
+        service_type : str, optional
+            Restricts the list to interfaces corresponding to services of this service type.
+            The list of possible values can be printed with
+            ``pyvo.registry.rtcons.SERVICE_TYPE_MAP.keys()``.
+
+        Returns
+        -------
+        list
+            A list of `~pyvo.registry.regtap.Interface` objects.
+
+        See Also
+        --------
+        get_service : when you already know that there is only one service of a specific service type.
+
+        """
+        interfaces = [interface for interface in self.interfaces
+                      if interface.is_user_visible]
+
+        if service_type is not None:
+            service_type = expand_stdid(rtcons.SERVICE_TYPE_MAP.get(service_type, service_type))
+            interfaces = [interface for interface in interfaces
+                          if interface.is_standard and interface.supports(service_type)]
+
+        return sorted(interfaces, key=lambda interface: interface.access_url)
+
     def search(self, *args, **keys):
         """
         assuming this resource refers to a searchable service, execute a
@@ -872,7 +967,7 @@ class RegistryResource(dalq.Record):
             raise dalq.DALServiceError(
                 f"Resource {self.ivoid} is not a searchable service")
 
-    def describe(self, verbose=False, width=78, file=None):
+    def describe(self, *, verbose=False, width=78, file=None):
         """
         Print a summary description of this resource.
 
@@ -886,7 +981,7 @@ class RegistryResource(dalq.Record):
             (often a DOI) -- will be printed if available.
         width : int
             Format the description with given character-width.
-        out : writable file-like object
+        file : writable file-like object
             If provided, write information to this output stream.
             Otherwise, it is written to standard out.
         """
@@ -895,11 +990,16 @@ class RegistryResource(dalq.Record):
         print("IVOA Identifier: " + self.ivoid, file=file)
         print("Access modes: " + ", ".join(sorted(self.access_modes())),
               file=file)
-
-        if len(self._mapping["access_urls"]) == 1:
-            print("Base URL: " + self.access_url, file=file)
-        else:
-            print("Multi-capability service -- use get_service()", file=file)
+        for interface in self.list_interfaces():
+            if interface.is_user_visible:
+                if interface.type == "vr:webbrowser":
+                    print(f"- webpage: {interface.access_url}", file=file)
+                else:
+                    service_item = (f"- {interface.standard_id.rsplit('/')[-1]}: "
+                                   f"{interface.access_url}")
+                    if interface.capability_description:
+                        service_item += f", description: {interface.capability_description}"
+                    print(textwrap.fill(service_item, width, subsequent_indent=" "), file=file)
 
         if self.res_description:
             print(file=file)
@@ -1010,7 +1110,7 @@ class RegistryResource(dalq.Record):
 
         return res
 
-    def get_tables(self, table_limit=20):
+    def get_tables(self, *, table_limit=20):
         """
         return the structure of the tables underlying the service.
 
