@@ -2,11 +2,8 @@
 """
 URL utils
 """
-from __future__ import (
-    absolute_import, division, print_function, unicode_literals)
-
-from six.moves.urllib.parse import urlparse, urlunparse
-from os.path import split as pathsplit, join as pathjoin
+from urllib.parse import urlparse, urlunparse
+from posixpath import split as pathsplit, join as pathjoin
 
 
 def url_sibling(url, sibling):
